import kshingle as ks
import pytest
import functools
import itertools
from collections import Counter


def test4b():
    db = {"qar": 2, "qbr": 3, "qcr": 4, "qdr": 5, "qer": 6, "qfr": 7}
    memo = ks.cews_cpu(
        db, wildcard="?", threshold=.8, min_samples_split=1, max_wildcards=1)
    assert memo == {'q?r': 9, 'qdr': 5, 'qer': 6, 'qfr': 7}


def test7():
    k = 5
    docs = [
        "Lorem ipsum dolor sit amet, consetetur sadipscing elitr, sed diam ",
        "nonumy eirmod tempor invidunt ut labore et dolore magna aliquyam ",
        "erat, sed diam voluptua. At vero eos et accusam et justo duo ",
        "dolores et ea rebum. Stet clita kasd gubergren, no sea takimata "]
    # generate all shingles
    shingled = [ks.shingleseqs_k(doc, k=k) for doc in docs]
    assert len(shingled) == len(docs)
    assert len(shingled[0]) == k
    # run CEWS algorithm
    db = functools.reduce(lambda x, y: x + Counter(itertools.chain(*y)),
                          shingled, Counter([]))
    memo = ks.cews_cpu(
        db, threshold=0.8, min_samples_split=10, max_wildcards=2)
    # encode shingles with patterns
    PATTERNS = ks.shingles_to_patterns(memo)
    encoded = ks.encode_with_patterns_cpu(shingled, PATTERNS, len(PATTERNS))
    assert sum([len(pats) for pats in PATTERNS.values()]) == len(memo)
    assert len(encoded) == len(shingled)
    for i in range(len(encoded)):
        assert len(encoded[i]) == len(shingled[i])
        for j in range(len(encoded[i])):
            assert len(encoded[i][j]) == len(shingled[i][j])



import kshingle as ks


def test1():
    shingles = ks.shingleset_k("abc", k=3)
    assert shingles == set(["a", "b", "c", "ab", "bc", "abc"])


def test2():
    s1 = ks.shingleset_k("abc", k=3)
    s2 = ks.shingleset_range("abc", 1, 3)
    s3 = ks.shingleset_list("abc", [1, 2, 3])
    assert s1 == set(["a", "b", "c", "ab", "bc", "abc"])
    assert s2 == s1
    assert s3 == s2


def test3():
    s1 = ks.shingleset_list("abcde", [2, 4])
    assert s1 == set(["ab", "bc", "cd", "de", "abcd", "bcde"])


def test4():
    s1 = ks.shingleset_range("abcde", 3, 5)
    assert s1 == set(["abc", "bcd", "cde", "abcd", "bcde", "abcde"])



__version__ = '0.9.6'

from .shingleseqs import (shingleseqs_k, shingleseqs_list, shingleseqs_range)
from .shingleset import (shingleset_k, shingleset_range, shingleset_list)
from .vocab import (
    identify_vocab, upsert_word_to_vocab, encode_with_vocab,
    shrink_k_backwards)
from .wildcard import wildcard_shinglesets
from .metrics import jaccard, jaccard_strings
from .cews import (
    expandshingle, cews, shingles_to_patterns, encode_with_patterns,
    encode_multi_match_corpus)
from .cews_cpu import cews_cpu, encode_with_patterns_cpu

# deprecated
from .vocab import encoded_with_vocab
